房间 (豆瓣)
Description: 房间电影简介和剧情介绍,房间影评、图片、预告片、影讯、论坛、在线购票
Keywords: 房间,Room,房间影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.224豆瓣电影Top250

# 房间 Room (2015)

导演: 伦尼·阿伯拉罕森
编剧: 艾玛·多诺霍
主演: 布丽·拉尔森 / 雅各布·特伦布莱 / 肖恩·布里吉格斯 / 温迪·古逊 / 阿曼达·布鲁盖尔 / 乔·平格 / 琼·艾伦 / 卡斯·安瓦尔 / 威廉姆·H·梅西 / 兰道尔·爱德华 / 罗德里戈·费尔南德斯-斯托尔 / 罗里·奥谢 / 汤姆·麦卡穆斯 / 杰克·富尔顿 / 梅根·帕克
类型: 剧情 / 家庭
制片国家/地区: 爱尔兰 / 加拿大 / 英国 / 美国
语言: 英语
上映日期: 2015-09-04(特柳赖德电影节) / 2015-10-23(多伦多) / 2016-01-15(爱尔兰/英国) / 2016-01-22(美国)
片长: 118分钟
又名: 不存在的房间(台) / 抖室(港)
IMDb: tt3170832
豆瓣评分
引用
8.8
356255人评价
5星
47.8%
4星
43.6%
3星
8.2%
2星
0.4%
1星
0.1%
好于 97% 剧情片
好于 97% 家庭片
想看 看过
评价:
推荐

## 房间的剧情简介 · · · · · ·

女孩乔伊（布丽·拉尔森 Brie Larson 饰）被一个叫“老尼克”的男人拐骗，之后被他囚禁在其房子后院的棚屋里长达七年之久。在此期间她遭到强奸，并生下儿子杰克（雅各布·特伦布莱 Jacob Tremblay 饰）。靠着老尼克时不时的物资补给，母子二人艰难度日。尽管如此，母亲还是竭尽所能，为儿子杰克创造了一个安全而开心的成长空间。这个狭小逼仄的房间，成了杰克生活成长的神奇小天地。在杰克度过了他的五岁生日后，母亲决定告诉他真相，在这个小小的房间外面，有着更广阔的世界。他们开始策划逃跑计划，决心要逃出这个囚禁他们的房间……
本片根据艾玛·唐纳修的同名小说改编。 ©豆瓣

## 房间的演职员 · · · · · · ( 全部 23 )

- 伦尼·阿伯拉罕森 导演
- 布丽·拉尔森 饰 乔伊 Ma
- 雅各布·特伦布莱 饰 杰克 Jack
- 肖恩·布里吉格斯 饰 老尼克 Old Nick
- 温迪·古逊 饰 谈话节目主持人 Talk Show Hostess
- 阿曼达·布鲁盖尔 饰 帕克警官 Officer Parker

## 房间的视频和图片 · · · · · · ( 预告片5 | 视频评论2 · 添加 | 图片729 · 添加 )

## 房间的获奖情况 · · · · · · ( 全部 )

- 第88届奥斯卡金像奖
- 最佳影片(提名)
- 艾德·格尼

- 第73届金球奖
- 电影类 最佳剧情片(提名)

- 第69届英国电影学院奖
- 电影奖 最佳女主角
- 布丽·拉尔森

## 喜欢这部电影的人也喜欢 · · · · · ·

  饮食男女

  步履不停

  海边的曼彻斯特

  小偷家族

  雨人

  一次别离

  婚姻故事

  海街日记

  寻梦环游记

  猫鼠游戏

我要写短评

## 房间的短评 · · · · · · ( 全部 90085 条 )

热门 / 最新 / 好友

### 5814 有用 Fay Kellum 看过 2015-10-20 13:15:26

电影开场一个半小时：卧槽原来这孩子是男的！！！

### 3524 有用 傻乐的猫 看过 2015-12-20 04:21:39

Babadook 2.0.娘送我一颗烂掉的牙，我还娘一头秀发，这母子情的信物把那些男女，男男，女女，各种爱情全比得没影了。最爱的角色其实是奶奶的丈夫，是要多温柔善良的人才能耐心去慢慢抚平脆弱的小心灵。

### 286 有用 同志亦凡人中文站 看过 2015-12-17 11:17:36

真人真事改编，可惜拍得流于表面了，完全没有被打动到。顶着锅盖说一句：小男孩演得其实比妈妈好...（第一次看女人在电影里素颜这么久）

### 2926 有用 影志 看过 2016-01-03 21:17:49

“我们不知道自己喜欢什么，所以每样都试试…这世界上有那么多东西，有时候还很恐怖，但是没关系，因为还是你和我在一起…”缩小的房间，变大的世界，2015像《阳光小美女》一样的惊喜黑马之作。结尾和房间再见有强力泪点：“再见盆栽，再见椅子一号和二号，再见桌子，再见衣柜，再见水槽，再见天窗…”

### 3111 有用 沉歌 看过 2016-02-21 03:01:03

小演员没提名最佳男主角，一定是为了把小金人让给莱奥纳多。

> 更多短评 90085条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 房间的影评 · · · · · · ( 全部 1566 条 )

热门 / 最新 / 好友
鱼丸粗面 2016-03-09 15:34:14

## 她被禽兽父亲囚禁性侵24年！电影的原型故事。

2008年4月19日，奥地利东部阿姆施泰滕镇。 73岁的当地人约瑟夫·弗莱茨勒将身患重病的19岁少女克斯汀送到医院，并告诉医生，这是他在家门口捡到的被丢弃的外孙女，而她的母亲——也就是约瑟夫的大女儿伊丽莎白——早在24年前就已经离家出走，并加入邪教。 克斯汀已经是约瑟夫... (展开)
4524 396 752回应 收起
石板栽花 2015-12-31 11:04:27

## 自由对于人性到底有多重要

自由对于人性到底有多重要 电影《房间》（Room 2015）讲述的故事并不复杂，但故事背后的政治隐喻细思起来挺有意思。“房间”其实是在自由的世界中圈起的一个不自由空间，但这个空间却被本片编导用来观测自由对于人的重要性，而观测的对象就是本故事中的5岁小男孩杰克。杰克的... (展开)
3690 450 299回应 收起
胖不动 2015-12-31 12:07:36

## 徘徊的十七岁

这篇影评可能有剧透

期待很久的一部片子，今天看完后，真的感到很大的惊喜。第一遍看完又立马看了第二遍。 前半段剧情丰富，引人入胜，特别是Jake装死逃离囚禁的那一段，真是扣人心弦，不禁为他捏了把汗，生怕他在跳下车前被发现，又害怕他跳下车找不到人。后半段，展示的是逃离囚禁的母子俩如何... (展开)
2014 85 83回应 收起
趣腻麻辣鸽鸡 2016-03-02 13:40:31

## 时间只是强效的麻醉药——评《房间》 8.5/10

这篇影评可能有剧透

《房间》是一部难得的电影。作为冲击奥斯卡的一部影片，当诱拐、监禁、性奴这类关键词给出来，一般认为最稳妥的处理方式就是渲染悲剧气氛，用写实的镜头语言讲述一个主角由自由、愉快的美好状态跌入一个万劫不复的深渊，再设计艰难逃脱的故事。两年前，《为奴十二年》就是如此... (展开)
1217 65 116回应 收起
小玄儿 2015-11-19 10:40:38

## 唤起心中童年的叙事诗——TIFF人民选择奖影片《房间》漫谈

唤起心中童年的叙事诗 这部影片的光环太多，可以写满整张宣传海报，如今俨然成为颁奖季中最佳故事片的热门选项。其实放眼背后主创团队，2014年圣丹斯独立电影节出跳的《弗兰克》导演，原班剪辑和音乐制作人马。外加请来了汤姆.霍伯导演，一系列影片《国王的演讲》《悲惨世界》... (展开)
638 58 84回应 收起
TheGZMovieGuy 2016-01-29 15:09:50

## 严肃影评#7：第一次看见世界的感觉 --- 8.5/10

小时候，总会有大人跟我们说：“一定要珍惜小时候的无忧无虑，长大了世界就会完全不一样了。”但作为涉世未深的小屁孩，我们总是挥霍着这些成年人看起来珍贵无比的时光。只有到我们终于长大了之后，才会感到遗憾。遗憾眼前的世界不再无忧无虑了，遗憾我们不能再天真无邪地大笑... (展开)
211 20 18回应 收起
Mandy王梦蝶 2016-01-13 04:17:38

## You and me against the world

这篇影评可能有剧透

电影的前半部分，相信所有观众都同我一样，为母子能否逃出生天捏一把冷汗，而当他们的计划眼看就要成功地时候，我心里也开始有一种隐隐的担忧了，Jack的人生观世界观是很狭隘的，尽管母亲尽可能地想保证他的身体健康（维生素啊，狭窄的空间还是让他运动啊），可是心理呢？他的... (展开)
129 5 11回应 收起
frozenmoon 2016-02-10 15:39:58

## 即便囚于牢笼，也不要丧失定义自由的能力

（文/杨时旸） 事实已经证明，今年真的是奥斯卡的小年，入选的片子大多数都没有惊喜，当然，那些片子谈不上是烂片，但问题在于都透露着一股看见开头就能猜到全部走向的平庸气味。这种正确得毫无瑕疵的状态有些让人厌倦。在几部热门电影之中，这部《房间》似乎还稍稍有些不... (展开)
158 51 20回应 收起
尼龙飞燕子 2016-01-09 15:55:38

## 我本想批判地看，结果我的心被活生生挖了出来【附访谈精彩片段】

这篇影评可能有剧透

首先要感谢毒舌电影公众号的大力推荐，使我身在LA没有错过这部电影的放映＋制作团队访谈。 有幸在UCLA附近的Hammer Museum看了这场电影，以及随后的创作团队访谈。这个活动是由纽约现代艺术博物馆主办的，精选了这一年上映的影片里最具价值（“historical significance“）的1... (展开)
106 26 22回应 收起
芳心暗许 2016-03-23 10:52:10

## Mom,say bye bye to room

女主凭借这部电影获得了奥斯卡影后，慕名而来。看完我只想说一句话：那个小男孩是没有提名么？完全可以提名最佳男主啊？难道是有年龄限制？另外，要不是我之前就知道他是男孩子，单看影片，他真的太漂亮了，还是长头发，就像一个洋娃娃，跟女孩子一样漂亮。 回到... (展开)
56 11 7回应 收起

> 更多影评 1566篇

添加新讨论

## 讨论区 · · · · · ·

在本片里，“狗”多次出现，具有什么作用? | 来自Shawty. | 3 回应 | 2022-11-17 23:08:40
母亲做得对 | 来自木英雄 |  | 2022-11-09 23:55:04
只有我觉得这部电影很一般吗？ | 来自理智喵～ | 69 回应 | 2022-11-08 00:06:38
为什么不挖出去呢 | 来自管.理.员 | 2 回应 | 2022-10-30 11:51:20
应该像审讯俘虏一样虐待老男人，让他说出密码 | 来自加 | 1 回应 | 2022-10-29 07:49:37

> 去这部影片的讨论区（全部140条）

## 关于《房间》的问题 · · · · · · ( 全部92个 )

- 影片快結尾母親病後回家母子在床孩子拉了一下母親衣服其實是想幹嘛？？ 29人回答
- 关于Old Nick? 22人回答

> 全部92个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 优酷视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)
- 自从爱上了精神病电影，我又活泼起来了 (meiya)

## 谁在看这部电影 · · · · · ·

- 杨坚强
  4分钟前 看过
- 千层度
  10分钟前 看过
- 邹邹什么的
  37分钟前 看过

551394人看过 / 273436人想看

订阅房间的评论:
feed: rss 2.0